/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/
#include "animation.h"
#include "node.h"
#include "lifecycle.h"
#include "stickman.h"
#include "graphicsview.h"

#include <QtCore>
#include <QtGui>

int main(int argc, char **argv)
{
    QApplication app(argc, argv);

    StickMan *stickMan = new StickMan;
    stickMan->setDrawSticks(false);

    QGraphicsScene *scene = new QGraphicsScene();
    scene->addItem(stickMan);
    scene->setBackgroundBrush(Qt::black);

    GraphicsView *view = new GraphicsView();
    view->setRenderHints(QPainter::Antialiasing);
    view->setTransformationAnchor(QGraphicsView::NoAnchor);
    view->setScene(scene);
    view->setViewportUpdateMode(QGraphicsView::FullViewportUpdate);
    view->showFullScreen();
    view->setFocus();
    
    LifeCycle *cycle = new LifeCycle(stickMan, view);
    cycle->setResetKey(Qt::Key_Escape);
    cycle->setDeathAnimation("animations/dead");
    
    cycle->addActivity("animations/jumping", Qt::Key_J);
    cycle->addActivity("animations/dancing", Qt::Key_D);
    cycle->addActivity("animations/chilling", Qt::Key_C);
    cycle->start();

    return app.exec();
}
