/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QABSTRACTANIMATION_P_H
#define QABSTRACTANIMATION_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of QIODevice. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <QtCore/qbasictimer.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qtimer.h>
#ifndef QT_EXPERIMENTAL_SOLUTION
#include <private/qobject_p.h>
#endif

QT_BEGIN_NAMESPACE

class QtAnimationGroup;
class QtAbstractAnimation;
#ifdef QT_EXPERIMENTAL_SOLUTION
class QtAbstractAnimationPrivate
#else
class QtAbstractAnimationPrivate : public QObjectPrivate
#endif
{
public:
    QtAbstractAnimationPrivate()
        : state(QtAbstractAnimation::NotRunning),
          direction(QtAbstractAnimation::Forward),
          deleteWhenStopped(false),
          totalCurrentTime(0),
          currentTime(0),
          loopCount(1),
          currentLoop(0),
          group(0)
    {
    }

    QtAbstractAnimation::State state;
    QtAbstractAnimation::Direction direction;
    bool deleteWhenStopped;
    void setState(QtAbstractAnimation::State state);

    int totalCurrentTime;
    int currentTime;
    int loopCount;
    int currentLoop;

    QtAnimationGroup *group;
#ifdef QT_EXPERIMENTAL_SOLUTION
    QtAbstractAnimation *q_ptr;
#endif

private:
    Q_DECLARE_PUBLIC(QtAbstractAnimation)
};


class QUnifiedTimer : public QObject
{
private:
    QUnifiedTimer();

public:
    static QUnifiedTimer *instance();

    void timerEvent(QTimerEvent *);
    void updateTimer();
    void registerAnimation(QtAbstractAnimation *animation);
    void unregisterAnimation(QtAbstractAnimation *animation);


private:
    void updateRecentlyStartedAnimations();

    QBasicTimer animationTimer, startAnimationTimer;
    QTime time;
    int lastTick;
    QList<QtAbstractAnimation*> animations, animationsToStart;
};

QT_END_NAMESPACE
#endif
