/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QANIMATIONGROUP_H
#define QANIMATIONGROUP_H

#if defined(QT_EXPERIMENTAL_SOLUTION)
# include "qabstractanimation.h"
#else
# include <QtCore/qabstractanimation.h>
#endif

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)


class QtAbstractAnimationPrivate;

class QtAnimationGroupPrivate;
class Q_ANIMATION_EXPORT QtAnimationGroup : public QtAbstractAnimation
{
    Q_OBJECT

public:
    QtAnimationGroup(QObject *parent = 0);
    ~QtAnimationGroup();

    QtAbstractAnimation *at(int index) const;
    QList<QtAbstractAnimation *> animations() const;
    int count() const;
    void add(QtAbstractAnimation *animation);
    void remove(QtAbstractAnimation *animation);
    void removeAt(int index);
    void clear();

protected:
    QtAnimationGroup(QtAnimationGroupPrivate &dd, QObject *parent);
    bool event(QEvent *event);

    virtual void animationInsertedAt(int index);
    virtual void animationRemovedAt(int index);

private:
    Q_DISABLE_COPY(QtAnimationGroup)
    Q_DECLARE_PRIVATE(QtAnimationGroup)
};

QT_END_NAMESPACE

QT_END_HEADER

#endif //QANIMATIONGROUP_H
