/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QPROPERTYANIMATION_H
#define QPROPERTYANIMATION_H

#if defined(QT_EXPERIMENTAL_SOLUTION)
# include "qanimation.h"
#else
# include <QtCore/qanimation.h>
#endif
#include <QtCore/qlist.h>
#include <QtCore/qpoint.h>
#include <QtCore/qvariant.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QPropertyAbstractAnimationPrivate;
class QtAnimationGroup;
class QtAnimationGroupPrivate;

class QtPropertyAnimationPrivate;
class Q_ANIMATION_EXPORT QtPropertyAnimation : public QtAnimation
{
    Q_OBJECT
    Q_PROPERTY(QByteArray propertyName READ propertyName WRITE setPropertyName) /*NOTIFY propertyNameChanged*/
    Q_PROPERTY(QObject* targetObject READ targetObject WRITE setTargetObject) /*NOTIFY targetObjectChanged*/

public:
    QtPropertyAnimation(QObject *parent = 0);
    QtPropertyAnimation(QObject *target, const QByteArray &propertyName, QObject *parent = 0);
    ~QtPropertyAnimation();

    QObject *targetObject() const;
    void setTargetObject(QObject *target);

    QByteArray propertyName() const;
    void setPropertyName(const QByteArray &propertyName);

    static QList<QtPropertyAnimation*> runningAnimations(QObject *object = 0);
    static QtPropertyAnimation* runningAnimation(QObject *object, QByteArray prop);

protected:
    bool event(QEvent *event);

    void updateCurrentValue(const QVariant &value);
    void updateState(QtAbstractAnimation::State oldState, QtAbstractAnimation::State newState);
private:
    Q_DISABLE_COPY(QtPropertyAnimation)
    Q_DECLARE_PRIVATE(QtPropertyAnimation)
    Q_PRIVATE_SLOT(d_func(), void _q_objectDeleted())
};

QT_END_NAMESPACE

QT_END_HEADER

#endif // QPROPERTYANIMATION_H
