/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QSTATEMACHINE_H
#define QSTATEMACHINE_H

#ifndef QT_STATEMACHINE_SOLUTION
#  include <QtCore/qstate.h>
#else
#  include "qstate.h"
#endif

#include <QtCore/qobject.h>
#include <QtCore/qset.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QEvent;
class QtAbstractState;
class QtState;

class QtStateMachinePrivate;
class Q_ANIMATION_EXPORT QtStateMachine : public QObject
{
    Q_OBJECT
public:

    enum Error {
        NoError, 
        NoInitialStateError,
        NoDefaultStateInHistoryState,
    };

    QtStateMachine(QObject *parent = 0);
    ~QtStateMachine();

    void addState(QtAbstractState *state);
    void removeState(QtAbstractState *state);

    QtState *rootState() const;

    QtAbstractState *initialState() const;
    void setInitialState(QtAbstractState *state);

    QtAbstractState *errorState() const;
    void setErrorState(QtAbstractState *state);

    Error error() const;
    QString errorString() const;
    void clearError();

    QtState::RestorePolicy globalRestorePolicy() const;
    void setGlobalRestorePolicy(QtState::RestorePolicy restorePolicy);

    void postEvent(QEvent *event, int delay = 0);

    QSet<QtAbstractState*> configuration() const;

#ifndef QT_NO_STATEMACHINE_EVENTFILTER
    bool eventFilter(QObject *watched, QEvent *event);
#endif

public Q_SLOTS:
    void start();
    void stop();

Q_SIGNALS:
    void started();
    void stopped();
    void finished();

protected:
    void postInternalEvent(QEvent *event);

    virtual void beginSelectTransitions(QEvent *event);
    virtual void endSelectTransitions(QEvent *event);

    virtual void beginMicrostep(QEvent *event);
    virtual void endMicrostep(QEvent *event);

    bool event(QEvent *e);

#ifdef QT_STATEMACHINE_SOLUTION
     QtStateMachinePrivate *d_ptr;
#endif

private:
    Q_DISABLE_COPY(QtStateMachine)
    Q_DECLARE_PRIVATE(QtStateMachine)
    Q_PRIVATE_SLOT(d_func(), void _q_start())
    Q_PRIVATE_SLOT(d_func(), void _q_process())
};

QT_END_NAMESPACE

QT_END_HEADER

#endif
